import { NextResponse } from "next/server"
import { z } from "zod"

import { db } from "@/lib/db"

export async function POST(request: Request) {
    const { gweet_id, user_id } = await request.json()

    const regweetSchema = z
        .object({
            gweet_id: z.string().cuid(),
            user_id: z.string().cuid(),
        })
        .strict()

    const zod = regweetSchema.safeParse({ gweet_id, user_id })

    if (!zod.success) {
        return NextResponse.json(
            {
                message: "Invalid request body",
                error: zod.error.formErrors,
            }, { status: 400 },
        )
    }

    try {
        const regweet = await db.regweet.findFirst({
            where: {
                gweetId: gweet_id,
                userId: user_id,
            },
        })

        if (regweet) {
            await db.regweet.delete({
                where: {
                    id: regweet.id,
                },
            })

            return NextResponse.json({ message: "Deleted gweet regweet" })
        } else {
            await db.regweet.create({
                data: {
                    gweetId: gweet_id,
                    userId: user_id,
                },
            })

            return NextResponse.json({ message: "Gweet regweeted" })
        }
    } catch (error: any) {
        return NextResponse.json({ error: error.message }, { status: 500 })
    }
}